@@ -11,12 +11,14 @@ from scipy.spatial.distance import squareform, pdist
 from scipy.stats import percentileofscore
 from sklearn.metrics import roc_auc_score
 import argparse
- 
-def read(f_expr="expression.txt", f_Xcen="Xcen.good"):
+import logging
+
+def read(f_expr="expression.txt", f_Xcen="Xcen.good", logger=logging):
 	#f_expr = "expression.txt"
 	#f_Xcen = "Xcen.good"
-	sys.stderr.write("Reading gene expression...\n")
-	sys.stderr.flush()
+	#sys.stderr.write("Reading gene expression...\n")
+	#sys.stderr.flush()
+	logger.info("Reading gene expression...")
 	f = open(f_expr)
 	h = f.readline().rstrip("\n").split("\t")[1:]
 	num_cell = len(h)
@@ -40,8 +42,9 @@ def read(f_expr="expression.txt", f_Xcen="Xcen.good"):
 		ig+=1
 	f.close()
 
-	sys.stderr.write("Reading cell coordinates...\n")
-	sys.stderr.flush()
+	#sys.stderr.write("Reading cell coordinates...\n")
+	#sys.stderr.flush()
+	logger.info("Reading cell coordinates...")
 	f = open(f_Xcen)
 	Xcen = np.empty((num_cell, 2), dtype="float32")
 	f.readline()
@@ -61,6 +64,20 @@ def do_one(args):
 	if not os.path.isdir(args.output):
 		os.mkdir(args.output)
 
+	logdir="%s/logs" % args.output
+	if not os.path.isdir(logdir):
+		os.mkdir(logdir)
+	log_file = "%s/real_%.2f_%.3f.out" % (logdir, args.rbp_p, args.examine_top)
+	logger = logging.getLogger("real_%.2f_%.3f" % (args.rbp_p, args.examine_top))
+	logger.setLevel(logging.DEBUG)
+
+	if not logger.hasHandlers():
+		handler = logging.FileHandler(log_file, "w")
+		handler.setFormatter(logging.Formatter("%(asctime)s - %(name)s - %(levelname)s - %(message)s"))
+		logger.addHandler(handler)
+		if args.verbose:
+			logger.addHandler(logging.StreamHandler())
+
 	t_overwrite = args.overwrite_input_bin
 	#if there is no binary input file, create one
 	check_required = ["expr.npy", "Xcen.npy", "genes.npy", "t_matrix_%s_%.2f.npy" % (args.matrix_type, args.rbp_p)]
@@ -71,29 +88,29 @@ def do_one(args):
 
 	expr, Xcen, genes, t_matrix = None, None, None, None
 	if t_overwrite:
-		expr, Xcen, genes = read(f_expr=args.expr, f_Xcen=args.centroid)
-		sys.stderr.write("Calculate all pairwise Euclidean distance between cells using their physical coordinates\n")
-		sys.stderr.flush()
+		expr, Xcen, genes = read(f_expr=args.expr, f_Xcen=args.centroid, logger=logger)
+		logger.info("Calculate all pairwise Euclidean distance between cells using their physical coordinates")
+		#sys.stderr.flush()
 		euc = squareform(pdist(Xcen, metric="euclidean"))
-		sys.stderr.write("Rank transform euclidean distance, and then apply exponential transform\n")
-		sys.stderr.flush()
-		t_matrix = spatial_genes.rank_transform_matrix(euc, reverse=False, rbp_p=rbp_p, matrix_type=matrix_type)
+		logger.info("Rank transform euclidean distance, and then apply exponential transform")
+		#sys.stderr.flush()
+		t_matrix = spatial_genes.rank_transform_matrix(euc, reverse=False, rbp_p=rbp_p, matrix_type=matrix_type, logger=logger)
 		np.save("%s/t_matrix_%s_%.2f.npy" % (args.output, args.matrix_type, args.rbp_p), t_matrix)
 		np.save("%s/expr.npy" % args.output, expr)
 		np.save("%s/Xcen.npy" % args.output, Xcen)
 		np.save("%s/genes.npy" % args.output, genes)
 	else:
-		sys.stderr.write("Using existing input binaries...\n")
-		sys.stderr.flush()
+		logger.info("Using existing input binaries...")
+		#sys.stderr.flush()
 		expr = np.load("%s/expr.npy" % args.output)
 		Xcen = np.load("%s/Xcen.npy" % args.output)
 		genes = np.load("%s/genes.npy" % args.output)
 		t_matrix = np.load("%s/t_matrix_%s_%.2f.npy" % (args.output, args.matrix_type, args.rbp_p))	
 
-	sys.stderr.write("Compute silhouette metric per gene\n")
-	sys.stderr.flush()
+	logger.info("Compute silhouette metric per gene")
+	#sys.stderr.flush()
 	examine_top = args.examine_top
-	res = spatial_genes.calc_silhouette_per_gene(genes=genes, expr=expr, matrix=t_matrix, matrix_type=matrix_type, examine_top=examine_top)
+	res = spatial_genes.calc_silhouette_per_gene(genes=genes, expr=expr, matrix=t_matrix, matrix_type=matrix_type, examine_top=examine_top, logger=logger)
 	if matrix_type=="sim":
 		f_name = "%s/silhouette.sim.exact.rbp.%.2f.top.%.3f.txt" % (args.output, rbp_p, examine_top)
 	else:
@@ -114,6 +131,7 @@ def main():
 	parser.add_argument("-r", "--rbp-p", dest="rbp_p", type=float, default=0.95, help="p parameter of RBP")
 	parser.add_argument("-m", "--matrix-type", dest="matrix_type", type=str, choices=["sim", "dissim"], help="whether to calculate similarity matrix or dissimilarity matrix", default="dissim")
 	parser.add_argument("-o", "--output-dir", dest="output", type=str, default=".", help="output directory")
+	parser.add_argument("-v", "--verbose", dest="verbose", action="store_true", help="print verbose messages to console")
 	
 	args = parser.parse_args()
 	do_one(args)
